// tailwind.config.js
module.exports = {
  mode: "jit",
  content: [
    "./components/**/*.{vue,js}",
    "./layouts/**/*.vue",
    "./pages/**/*.vue",
    "./plugins/**/*.{js,ts}",
  ],
  media: false, // or 'media' or 'class'
  theme: {
    extend: {

      screens: {
        sm: '640px',
        md: '768px',
        lg: '1024px',
        xl: '1280px',
        '2xl': '1536px'
      },
      colors: {
        transparent: 'transparent',
        current: 'currentColor',
        black: '#140505',
        white: '#fff',
        background: '#f8f8f8',
        primary: {
          900: '#e94f2e',
          800: '#eb6043',
          700: '#ec7258',
          600: '#f0846d',
          500: '#f19482',
          400: '#f3a695',
          300: '#f6b8aa',
          200: '#f8cac0',
          100: '#fadcd4',
          50: '#fdecea'
        },
        secondary: {
          900: '#3585b4',
          800: '#4891bc',
          700: '#5d9cc3',
          600: '#72a9ca',
          500: '#86b5d3',
          400: '#99c1da',
          300: '#aecde1',
          200: '#c1dae9',
          100: '#d6e6f0',
          50: '#eaf2f8'
        },
        gray: {
          900: '#292929',
          800: '#3d3d3d',
          700: '#535353',
          600: '#686968',
          500: '#7f7f7f',
          400: '#939393',
          300: '#a8a8a8',
          200: '#bfbfbf',
          100: '#d3d3d3',
          50: '#eaeaea'
        },
        red: {
          900: '#e20c3c',
          800: '#e4244f',
          700: '#e83c62',
          600: '#eb5677',
          500: '#ed6e8a',
          400: '#f1869c',
          300: '#f29eb1',
          200: '#f6b5c3',
          100: '#f8ced8',
          50: '#fce6ea'
        },
        yellow: {
          900: '#e3c008',
          800: '#e5c720',
          700: '#e9cc39',
          600: '#ead351',
          500: '#edda6b',
          400: '#f1df83',
          300: '#f3e59b',
          200: '#f7ebb4',
          100: '#f8f2cd',
          50: '#fcf8e5'
        },
        green: {
          900: '#3ab700',
          800: '#4ebf18',
          700: '#60c633',
          600: '#75cc4c',
          500: '#89d365',
          400: '#9bdb80',
          300: '#b0e398',
          200: '#c3eab2',
          100: '#d8f1cb',
          50: '#eaf8e4'
        },
        teal: {
          900: '#35b4a6',
          800: '#48bcaf',
          700: '#5dc3b7',
          600: '#72cac0',
          500: '#86d3ca',
          400: '#99dad3',
          300: '#aee1db',
          200: '#c1e9e3',
          100: '#d6f0ec',
          50: '#eaf8f6'
        },
        purple: {
          900: '#9233ea',
          800: '#9e46eb',
          700: '#a85ced',
          600: '#b370f0',
          500: '#be85f1',
          400: '#c998f4',
          300: '#d3acf7',
          200: '#dec1f8',
          100: '#e9d5fa',
          50: '#f3ebfd'
        },
        brown: {
          900: '#713e12',
          800: '#7f5129',
          700: '#8d6441',
          600: '#9b7959',
          500: '#a98c71',
          400: '#b79f88',
          300: '#c6b2a0',
          200: '#d3c4b7',
          100: '#e3d9d0',
          50: '#f1ebe6'
        }
      },
      spacing: {
        px: '1px',
        0: '0px',
        0.5: '0.125rem',
        1: '0.25rem',
        1.5: '0.375rem',
        2: '0.5rem',
        2.5: '0.625rem',
        3: '0.75rem',
        3.5: '0.875rem',
        4: '1rem',
        5: '1.25rem',
        6: '1.5rem',
        7: '1.75rem',
        8: '2rem',
        9: '2.25rem',
        10: '2.5rem',
        11: '2.75rem',
        12: '3rem',
        14: '3.5rem',
        16: '4rem',
        20: '5rem',
        24: '6rem',
        28: '7rem',
        32: '8rem',
        34: '8.5rem',
        36: '9rem',
        40: '10rem',
        44: '11rem',
        48: '12rem',
        52: '13rem',
        56: '14rem',
        60: '15rem',
        64: '16rem',
        72: '18rem',
        80: '20rem',
        88: '22rem',
        96: '24rem'
      },
    },
  },
  variants: {
    extend: {},
  },
  plugins: [
    require('@tailwindcss/forms'),
    require('@tailwindcss/line-clamp'),
  ],
};